/*
 GAMP - (c) 2001 - Renato R. Santana <rrsantana@yahoo.com>
 
 This is a simple example program on how to make use of gamplib.
   
 This file is part of GAMP, the GNU Amiga Module Player
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with This program; see the file COPYING.  If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <stdio.h>
#include <unistd.h>
#include <signal.h>

#include "gamp.h"		

void int_handler(void);

main(int argc, char *argv[]) {
	int initial_pattern = 0;
	int	initial_speed = 6;
	int	ret = 0;
	int t, i;
	int	last_tick;
	
    if (argc < 2){
		printf("\nUsage: mp modfile [options]\n\n");
		exit(1);
	}
	if (argc > 2)
		initial_pattern = atoi(argv[2]);

	if (argc > 3)
		initial_speed = atoi(argv[3]);
	
	oss_open();
	if (mp_load(argv[1]))
		goto main_exit;
	printf("Module loaded\n");
	if (mp_init())
		goto main_exit;

	signal(SIGINT, (void *)int_handler);
	
	modctl.pos = initial_pattern;
	modctl.speed = initial_speed;
	reset_speed();
	/* calculates the number of ticks that will fill one fragment */
	t = oss_driver.fragsize / oss_driver.channels / (oss_driver.bits / 8);
	last_tick = -1;
	while(!ret) {
		ret = mp_play(t);
		if (last_tick != modctl.tick) {
			printf("\r %02d    %03d   %02d  %03d/%03d", modctl.speed, modctl.bpm, modctl.row, modctl.pos, modctl.maxpos);
			fflush(stdout);
			last_tick = modctl.tick;
		}
		usleep(5000);
	}
	printf("\nStoping...\n");
	
main_exit:
	mp_stop();
	mp_unload();
	oss_close();
	signal(SIGINT, SIG_DFL);
}


void int_handler(void) {
	printf("\nCaught INT signal, exiting.\n");
	signal(SIGINT, SIG_DFL);
	mp_stop();
	mp_unload();
    oss_close();
    exit(1);
}

